==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/elasticache/kotlin/inputs/UserAuthenticationModeArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.elasticache.kotlin.inputs

import com.pulumi.aws.elasticache.inputs.UserAuthenticationModeArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property passwordCount
 * @property passwords Specifies the passwords to use for authentication if `type` is set to `password`.
 * @property type Specifies the authentication type. Possible options are: `password`, `no-password-required` or `iam`.
 */
public data class UserAuthenticationModeArgs(
    public val passwordCount: Output<Int>? = null,
    public val passwords: Output<List<String>>? = null,
    public val type: Output<String>,
) : ConvertibleToJava<com.pulumi.aws.elasticache.inputs.UserAuthenticationModeArgs> {
    override fun toJava(): com.pulumi.aws.elasticache.inputs.UserAuthenticationModeArgs =
        com.pulumi.aws.elasticache.inputs.UserAuthenticationModeArgs.builder()
            .passwordCount(passwordCount?.applyValue({ args0 -> args0 }))
            .passwords(passwords?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .type(type.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [UserAuthenticationModeArgs].
 */
@PulumiTagMarker
public class UserAuthenticationModeArgsBuilder internal constructor() {
    private var passwordCount: Output<Int>? = null

    private var passwords: Output<List<String>>? = null

    private var type: Output<String>? = null

    /**
     * @param value
     */
    @JvmName("jagctsqrmyxcgrhq")
    public suspend fun passwordCount(`value`: Output<Int>) {
        this.passwordCount = value
    }

    /**
     * @param value Specifies the passwords to use for authentication if `type` is set to `password`.
     */
    @JvmName("cdeltumesqslnmth")
    public suspend fun passwords(`value`: Output<List<String>>) {
        this.passwords = value
    }

    @JvmName("joxelnfefwophtga")
    public suspend fun passwords(vararg values: Output<String>) {
        this.passwords = Output.all(values.asList())
    }

    /**
     * @param values Specifies the passwords to use for authentication if `type` is set to `password`.
     */
    @JvmName("yxfancgcfxvsbout")
    public suspend fun passwords(values: List<Output<String>>) {
        this.passwords = Output.all(values)
    }

    /**
     * @param value Specifies the authentication type. Possible options are: `password`, `no-password-required` or `iam`.
     */
    @JvmName("wqmhbleevaifkjps")
    public suspend fun type(`value`: Output<String>) {
        this.type = value
    }

    /**
     * @param value
     */
    @JvmName("egxwtyashrbsvsie")
    public suspend fun passwordCount(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.passwordCount = mapped
    }

    /**
     * @param value Specifies the passwords to use for authentication if `type` is set to `password`.
     */
    @JvmName("bvsjfmolihkgqsqf")
    public suspend fun passwords(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.passwords = mapped
    }

    /**
     * @param values Specifies the passwords to use for authentication if `type` is set to `password`.
     */
    @JvmName("gshdpepegifesjov")
    public suspend fun passwords(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.passwords = mapped
    }

    /**
     * @param value Specifies the authentication type. Possible options are: `password`, `no-password-required` or `iam`.
     */
    @JvmName("dvnpyplkevniukru")
    public suspend fun type(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    internal fun build(): UserAuthenticationModeArgs = UserAuthenticationModeArgs(
        passwordCount = passwordCount,
        passwords = passwords,
        type = type ?: throw PulumiNullFieldException("type"),
    )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/elasticache/kotlin/inputs/UserAuthenticationModeArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.elasticache.kotlin.inputs

import com.pulumi.aws.elasticache.inputs.UserAuthenticationModeArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property passwordCount
 * @property passwords Specifies the passwords to use for authentication if `type` is set to `password`.
 * @property type Specifies the authentication type. Possible options are: `password`, `no-password-required` or `iam`.
 */
public data class UserAuthenticationModeArgs(
    public val passwordCount: Output<Int>? = null,
    public val passwords: Output<List<String>>? = null,
    public val type: Output<String>,
) : ConvertibleToJava<com.pulumi.aws.elasticache.inputs.UserAuthenticationModeArgs> {
    override fun toJava(): com.pulumi.aws.elasticache.inputs.UserAuthenticationModeArgs =
        com.pulumi.aws.elasticache.inputs.UserAuthenticationModeArgs.builder()
            .passwordCount(passwordCount?.applyValue({ args0 -> args0 }))
            .passwords(passwords?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .type(type.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [UserAuthenticationModeArgs].
 */
@PulumiTagMarker
public class UserAuthenticationModeArgsBuilder internal constructor() {
    private var passwordCount: Output<Int>? = null

    private var passwords: Output<List<String>>? = null

    private var type: Output<String>? = null

    /**
     * @param value
     */
    @JvmName("xovucjtbsqkvlcbg")
    public suspend fun passwordCount(`value`: Output<Int>) {
        this.passwordCount = value
    }

    /**
     * @param value Specifies the passwords to use for authentication if `type` is set to `password`.
     */
    @JvmName("pqoenjhdscghheqa")
    public suspend fun passwords(`value`: Output<List<String>>) {
        this.passwords = value
    }

    @JvmName("ffotnliuwqkgekmw")
    public suspend fun passwords(vararg values: Output<String>) {
        this.passwords = Output.all(values.asList())
    }

    /**
     * @param values Specifies the passwords to use for authentication if `type` is set to `password`.
     */
    @JvmName("orrbtfbieukaurxl")
    public suspend fun passwords(values: List<Output<String>>) {
        this.passwords = Output.all(values)
    }

    /**
     * @param value Specifies the authentication type. Possible options are: `password`, `no-password-required` or `iam`.
     */
    @JvmName("ngjgnbpputhoikpg")
    public suspend fun type(`value`: Output<String>) {
        this.type = value
    }

    /**
     * @param value
     */
    @JvmName("vpaxjvhwyphyxrdn")
    public suspend fun passwordCount(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.passwordCount = mapped
    }

    /**
     * @param value Specifies the passwords to use for authentication if `type` is set to `password`.
     */
    @JvmName("nyxfmblytlolexbe")
    public suspend fun passwords(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.passwords = mapped
    }

    /**
     * @param values Specifies the passwords to use for authentication if `type` is set to `password`.
     */
    @JvmName("ybdgueoxfpmsjqdl")
    public suspend fun passwords(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.passwords = mapped
    }

    /**
     * @param value Specifies the authentication type. Possible options are: `password`, `no-password-required` or `iam`.
     */
    @JvmName("hvnagjfpoxpyylwp")
    public suspend fun type(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    internal fun build(): UserAuthenticationModeArgs = UserAuthenticationModeArgs(
        passwordCount = passwordCount,
        passwords = passwords,
        type = type ?: throw PulumiNullFieldException("type"),
    )
}
